@@ -59,6 +59,10 @@ static void debug_big_cb(GtkWidget* w, gpointer data)
 {
   guppi_create_debug_datasets(DebugDataBig);
 }
+static void debug_price_cb(GtkWidget* w, gpointer data)
+{
+  guppi_create_debug_datasets(DebugDataPrice);
+}
 #endif
 
 #ifdef GNOME_ENABLE_DEBUG
@@ -75,6 +79,9 @@ static GnomeUIInfo debug_menu[] = {
     { GNOME_APP_UI_ITEM, N_("Make Basic Debug Datasets"), N_("Create some basic data for debugging and playing around"), debug_basic_cb, NULL, NULL, \
     GNOME_APP_PIXMAP_NONE, NULL, 
     0, (GdkModifierType) 0, NULL},
+    { GNOME_APP_UI_ITEM, N_("Make Price Bar Debug Datasets"), N_("Create some price data for debugging and playing around"), debug_price_cb, NULL, NULL, \
+    GNOME_APP_PIXMAP_NONE, NULL, 
+    0, (GdkModifierType) 0, NULL},
     GNOMEUIINFO_END
 };
 #endif
