@@ -26,12 +26,12 @@
 
 #include "cplot-component.h"
 #include "PlotComponent.h"
-#include <bonobo/gnome-main.h>
 #include <goose/RealSet.h>
 #include <libguppi/scalardata.h>
 #include <libguppi/barplotstate.h>
 #include "corba-util.h"
 #include "cplot-vector.h"
+#include <bonobo/gnome-main.h>
 
 //////////////////////////////////// CPlotComponent object and PlotComponent CORBA interface
 typedef struct _CPlotPriv CPlotPriv;
@@ -41,7 +41,7 @@ struct _CPlotPriv {
 
 #define PRIV(cplot) ((CPlotPriv*)cplot->priv)
 
-static GnomeObjectClass* parent_class = NULL;
+static GnomeUnknownClass* parent_class = NULL;
 
 static void cplot_component_class_init(CPlotComponentClass* klass);
 static void cplot_component_init(CPlotComponent* cpc);
@@ -57,7 +57,7 @@ impl_GNOME_Plot_PlotComponent_plot_type_supported(PortableServer_Servant servant
                                                   const CORBA_char * plot_type,
                                                   CORBA_Environment *ev)
 {
-  CPlotComponent *cpc = CPLOT_COMPONENT (gnome_object_from_servant (servant));  
+  CPlotComponent *cpc = CPLOT_COMPONENT (gnome_unknown_from_servant (servant));  
 
   return PlotComponent::plot_type_supported(plot_type);
 }
@@ -67,7 +67,7 @@ impl_GNOME_Plot_PlotComponent_set_plot_type(PortableServer_Servant servant,
                                             const CORBA_char * plot_type,
                                             CORBA_Environment *ev)
 {
-  CPlotComponent *cpc = CPLOT_COMPONENT (gnome_object_from_servant (servant));  
+  CPlotComponent *cpc = CPLOT_COMPONENT (gnome_unknown_from_servant (servant));  
 
   // FIXME if this returns false, must raise an exception!
   bool result = cpc->pc->set_plot_type(plot_type);
@@ -79,7 +79,7 @@ static GNOME_Plot_PlotState
 impl_GNOME_Plot_PlotComponent_get_plot(PortableServer_Servant servant,
                                        CORBA_Environment *ev)
 {
-  CPlotComponent *cpc = CPLOT_COMPONENT (gnome_object_from_servant (servant));  
+  CPlotComponent *cpc = CPLOT_COMPONENT (gnome_unknown_from_servant (servant));  
 
   return cpc->pc->state_object();
 }
@@ -88,7 +88,7 @@ static GNOME_Plot_VectorFactory
 impl_GNOME_Plot_PlotComponent_get_vector_factory(PortableServer_Servant servant,
                                                  CORBA_Environment *ev)
 {
-  CPlotComponent *cpc = CPLOT_COMPONENT (gnome_object_from_servant (servant));  
+  CPlotComponent *cpc = CPLOT_COMPONENT (gnome_unknown_from_servant (servant));  
 
   return CORBA_Object_duplicate(plot_vector_factory_get_reference(PRIV(cpc)->pvf), ev);
 }
@@ -104,13 +104,13 @@ init_corba_class (void)
   FILL_EPV(get_vector_factory);
   
   /* Setup the vector of epvs */
-  gnome_plotcomponent_vepv.GNOME_obj_epv = &gnome_obj_epv;
+  gnome_plotcomponent_vepv.GNOME_Unknown_epv = &gnome_unknown_epv;
   gnome_plotcomponent_vepv.GNOME_Plot_PlotComponent_epv = &gnome_plotcomponent_epv;
 }
 #undef FILL_EPV
 
 static CORBA_Object
-create_cplot_component (GnomeObject *object)
+create_cplot_component (GnomeUnknown *object)
 {
   POA_GNOME_Plot_PlotComponent *servant;
   CORBA_Object o;
@@ -125,7 +125,7 @@ create_cplot_component (GnomeObject *object)
     return CORBA_OBJECT_NIL;
   }
   
-  return gnome_object_activate_servant (object, servant);
+  return gnome_unknown_activate_servant (object, servant);
 }
 
 
@@ -146,7 +146,7 @@ cplot_component_get_type (void)
       (GtkClassInitFunc) NULL
     };
 
-    type = gtk_type_unique (gnome_object_get_type (), &info);
+    type = gtk_type_unique (gnome_unknown_get_type (), &info);
   }
 
   return type;
@@ -156,9 +156,9 @@ static void
 cplot_component_class_init (CPlotComponentClass *klass)
 {
   GtkObjectClass *object_class = (GtkObjectClass *) klass;
-  GnomeObjectClass* gobject_class = (GnomeObjectClass*) klass;
+  GnomeUnknownClass* gobject_class = (GnomeUnknownClass*) klass;
 
-  parent_class = (GnomeObjectClass*)gtk_type_class (gnome_object_get_type ());
+  parent_class = (GnomeUnknownClass*)gtk_type_class (gnome_unknown_get_type ());
 	
   object_class->destroy = cplot_component_destroy;
 
@@ -192,7 +192,7 @@ cplot_component_construct (CPlotComponent* cpc,
                            GNOME_Plot_PlotComponent corba_pc,
                            const gchar* default_plot_type)
 {
-  gnome_object_construct (GNOME_OBJECT (cpc), corba_pc);
+  gnome_unknown_construct (GNOME_UNKNOWN (cpc), corba_pc);
 
   cpc->pc = new PlotComponent(default_plot_type);
 
@@ -214,7 +214,7 @@ cplot_component_new(const char* default_plot_type)
 
   cpc = (CPlotComponent*)gtk_type_new (cplot_component_get_type ());
 
-  corba_pc = create_cplot_component (GNOME_OBJECT (cpc));
+  corba_pc = create_cplot_component (GNOME_UNKNOWN (cpc));
   if (corba_pc == CORBA_OBJECT_NIL){
     gtk_object_destroy (GTK_OBJECT (cpc));
     return NULL;
