@@ -19,7 +19,7 @@ typedef struct {
   GnomeContainer *container;
   GnomeClientSite* client_site;
   GtkWidget *box;
-  GnomeObjectClient *server;
+  GnomeUnknownClient *server;
   CORBA_Object plot_component;
 } Application;
 
@@ -50,13 +50,13 @@ check_errors()
 }
 
 
-static GnomeObjectClient *
+static GnomeUnknownClient *
 launch_server (GnomeContainer *container, char *goadid, GnomeClientSite* client_site)
 {
-  GnomeObjectClient *object_server;
+  GnomeUnknownClient *object_server;
 	
   printf ("Launching...\n");
-  object_server = gnome_object_activate_with_goad_id (NULL, goadid, 0, NULL);
+  object_server = gnome_unknown_activate_with_goad_id (NULL, goadid, 0, NULL);
   printf ("Return: %p\n", object_server);
   if (!object_server){
     g_warning (_("Can not activate object_server\n"));
@@ -71,7 +71,7 @@ launch_server (GnomeContainer *container, char *goadid, GnomeClientSite* client_
   return object_server;
 }
 
-static GnomeObjectClient *
+static GnomeUnknownClient *
 add_cmd (GtkWidget *widget, Application *app, char *server_goadid)
 {
   GtkWidget *frame, *socket, *w;
@@ -86,9 +86,9 @@ add_cmd (GtkWidget *widget, Application *app, char *server_goadid)
         return NULL;
 
       app->plot_component = 
-        GNOME_obj_query_interface(GNOME_OBJECT(app->server)->object,
-                                  "IDL:GNOME/Plot/PlotComponent:1.0",
-                                  &ev);
+        GNOME_Unknown_query_interface(GNOME_UNKNOWN(app->server)->object,
+                                      "IDL:GNOME/Plot/PlotComponent:1.0",
+                                      &ev);
       check_errors();
 
       GNOME_Plot_PlotComponent_set_plot_type(app->plot_component, "Bar",
@@ -241,7 +241,7 @@ application_new (void)
   app->app = gnome_app_new ("plot_comp_test", "Testing Plot Component");
   app->container = GNOME_CONTAINER (gnome_container_new ());
   app->client_site = gnome_client_site_new (app->container);
-  gnome_container_add (app->container, GNOME_OBJECT (app->client_site));
+  gnome_container_add (app->container, GNOME_UNKNOWN (app->client_site));
 
   app->box = gtk_vbox_new (FALSE, 0);
   gtk_widget_show (app->box);
