@@ -30,6 +30,7 @@
 
 #include "guppi.h"
 #include "libguppi/data.h"
+#include "libguppi/datagroupedit.h"
 
 class DataEdit : public Data::View {
 public:
@@ -54,6 +55,9 @@ private:
   GtkWidget* scalar_value_entry_;
   GtkWidget* string_value_entry_;
   GtkWidget* clist_;
+  GtkWidget* sw_;
+  
+  DataGroupEdit group_edit_;
 
   bool changing_name_;
   bool changing_value_;
