@@ -126,7 +126,7 @@ BarPlotState::grab_data(Data* d)
     {
       data_->ref();
       
-      data_->data_model.add_view(*this);
+      data_->data_model.add_view(this);
     }      
 }
 
@@ -135,7 +135,7 @@ BarPlotState::release_data()
 {
   if (data_ != 0)
     {
-      data_->data_model.remove_view(*this);
+      data_->data_model.remove_view(this);
       if (data_->unref() == 0) delete data_;
       data_ = 0;
     }
@@ -158,7 +158,7 @@ BarPlotState::grab_labels(Data* d)
     {
       labels_->ref();
       
-      labels_->data_model.add_view(*this);
+      labels_->data_model.add_view(this);
     } 
 }
 
@@ -167,7 +167,7 @@ BarPlotState::release_labels()
 {
   if (labels_ != 0)
     {
-      labels_->data_model.remove_view(*this);
+      labels_->data_model.remove_view(this);
       if (labels_->unref() == 0) delete labels_;
       labels_ = 0;
     }
