@@ -254,7 +254,8 @@ guppi_lineplot_render (GnomeCanvasItem *item,
 
   get_info(gl, &xtrans, &ytrans, &N, &state, &layer);
 
-  if (N == 0) return;  
+  if (N < 2) 
+    return;  
 
   // consider the affine we got in update() (i2c)
   Affine i2c(gl->a);
