@@ -28,7 +28,7 @@
 
 DataOption::DataOption()
   : store_(0), option_(0), menu_(0), current_(0), 
-    show_type_(Data::DataTypeEnd),
+    show_type_(Data::Invalid),
     changing_data_(false), cblist_(this)
 {
 
@@ -53,7 +53,8 @@ DataOption::restrict_type(Data::DataType t)
 void 
 DataOption::set_store(DataStore* store)
 {
-  if (store_ == store) return;
+  if (store_ == store) 
+    return;
 
   if (store_ != 0)
     {
@@ -221,8 +222,8 @@ DataOption::make_data_menu()
           Data* d = *i;
 
           // Don't show data of the wrong type.
-          if (show_type_ != Data::DataTypeEnd && 
-              d->type() != show_type_)
+          if (show_type_ != Data::Invalid && 
+              !d->is_a(show_type_))
             {
               ++i;
               continue;
@@ -262,6 +263,10 @@ DataOption::make_data_menu()
           gtk_option_menu_set_history(GTK_OPTION_MENU(option_), active);
         }
     }
+#ifdef GNOME_ENABLE_DEBUG
+  else
+    g_warning("No DataStore for DataOption?");
+#endif
 }
 
 void
