@@ -51,6 +51,7 @@ private:
   // const has no meaning for the gnome-print API
   mutable GnomeFont* font_;
   mutable GnomeDisplayFont* cached_display_font_;
+  mutable GdkFont* fallback_;
 
   GFontInternal(GnomeFont* font);
   GFontInternal();
@@ -235,7 +236,7 @@ GFontInternal::get_font(const gchar* name, GFont::FontWeightType weight, bool it
 }
 
 GFontInternal::GFontInternal(GnomeFont* font)
-  : font_(font), cached_display_font_(0)
+  : font_(font), cached_display_font_(0), fallback_(0)
 {
   
 }
@@ -244,6 +245,9 @@ GFontInternal::~GFontInternal()
 {
   if (font_ != 0)
     gtk_object_unref(GTK_OBJECT(font_));
+
+  if (fallback_ != 0)
+    gdk_font_unref(fallback_);
 }
 
 double 
@@ -290,13 +294,25 @@ GFontInternal::gdk_font(double scale)
       cached_display_font_ = gnome_font_get_display_font(font_);
     }
   
-  if (cached_display_font_ != 0)
+  if (cached_display_font_ != 0 && cached_display_font_->gdk_font != 0)
     {
       return cached_display_font_->gdk_font;
     }
   else 
     {
-      return 0;
+      if (fallback_ == 0)
+        {
+          // we own the implicit initial reference count
+          fallback_ = gdk_font_load("-*-*-medium-r-*-*-*-*-*-*-*-*-*-*");
+          if (fallback_ == 0)
+            fallback_ = gdk_font_load("fixed");
+          if (fallback_ == 0)
+            fallback_ = gdk_font_load("helvetica");
+
+          g_debug("Falling back to random X font because gnome-print returned no appropriate match for %s %s", font_name(), fallback_ ? "" : "(fallback failed to load!)");
+        }
+
+      return fallback_;
     }
 }
 
