@@ -622,7 +622,7 @@ MarkerPaletteEdit::grab_palette(MarkerPalette* palette)
 {
   if (palette != 0)
     {
-      palette->palette_model.add_view(*this);
+      palette->palette_model.add_view(this);
       g_return_if_fail(palette_ == 0);
       palette_ = palette;
     }
@@ -633,7 +633,7 @@ MarkerPaletteEdit::release_palette()
 {
   if (palette_ != 0)
     {
-      palette_->palette_model.remove_view(*this);
+      palette_->palette_model.remove_view(this);
       palette_ = 0;
     }
 }
