@@ -46,7 +46,7 @@ PiePlot::PiePlot(DataStore* datastore)
   DataStore::iterator i = datastore->begin();
   while (i != datastore->end())
     {
-      if ((*i)->type() == Data::Scalar)
+      if ((*i)->is_a(Data::Scalar))
         {
           if (scalar_data == 0)
             {
@@ -55,7 +55,7 @@ PiePlot::PiePlot(DataStore* datastore)
           else if (label_data != 0)
             break;
         }
-      else if ((*i)->type() == Data::Label)
+      else if ((*i)->is_a(Data::Label))
         {
           if (label_data == 0)
             {
