@@ -30,6 +30,12 @@
 #include "scalardata.h"
 #include "pointtiles.h"
 #include "guppi-math.h"
+#include "datagroup.h"
+#include "datedata.h"
+
+// FIXME should draw the open, open-close range of main bar, then close in a single 
+// call to get a nice bevel; then add the ends of the main bar. Avoids ugliness when
+// open/close are right on the end.
 
 void 
 guppi_draw_price_bar(RGB& rgb, const RGB::Context& ctx,
@@ -46,14 +52,14 @@ guppi_draw_price_bar(RGB& rgb, const RGB::Context& ctx,
 
   // open bar on left
   // + 1 to be at least one pixel
-  pts[2].x = time - ctx.line_width() - 1; 
+  pts[2].x = time - ctx.line_width()*1.5 - 1; 
   pts[2].y = open;
 
   pts[3].x = time;
   pts[3].y = open;
 
   // close bar on right
-  pts[4].x = time + ctx.line_width() + 1; 
+  pts[4].x = time + ctx.line_width()*1.5 + 1; 
   pts[4].y = close;
 
   pts[5].x = time;
@@ -77,7 +83,7 @@ guppi_draw_price_bar_no_close(RGB& rgb, const RGB::Context& ctx,
 
   // open bar on left
   // + 1 to be at least one pixel
-  pts[2].x = time - ctx.line_width() - 1; 
+  pts[2].x = time - ctx.line_width()*1.5 - 1; 
   pts[2].y = open;
 
   pts[3].x = time;
@@ -100,7 +106,7 @@ guppi_draw_price_bar_no_open(RGB& rgb, const RGB::Context& ctx,
   pts[1].y = hi;
 
   // close bar on right
-  pts[2].x = time + ctx.line_width() + 1; 
+  pts[2].x = time + ctx.line_width()*1.5 + 1; 
   pts[2].y = close;
 
   pts[3].x = time;
@@ -563,12 +569,22 @@ guppi_draw_pricebars(XyPriceBars* layer,
 
   //// Extract time and price data
 
-  Data* time_data = layer->time_data();
+  DataGroup* price_data_group = layer->data()->cast_to_group();
 
-  const ScalarData* hi_data = layer->price_data(XyPriceBars::Hi);
-  const ScalarData* lo_data = layer->price_data(XyPriceBars::Lo);
-  const ScalarData* open_data = layer->price_data(XyPriceBars::Open);
-  const ScalarData* close_data = layer->price_data(XyPriceBars::Close);
+  if (price_data_group == 0)
+    return;
+
+  Data* time_data = price_data_group->get_data((int)PriceDates); 
+
+  const Data* hi_d = price_data_group->get_data((int)PriceHighs);
+  const Data* lo_d = price_data_group->get_data((int)PriceLows);
+  const Data* open_d = price_data_group->get_data((int)PriceOpens);
+  const Data* close_d = price_data_group->get_data((int)PriceCloses);
+
+  const ScalarData* hi_data = hi_d ? hi_d->cast_to_scalar() : 0;
+  const ScalarData* lo_data = lo_d ? lo_d->cast_to_scalar() : 0;
+  const ScalarData* open_data = open_d ? open_d->cast_to_scalar() : 0;
+  const ScalarData* close_data = close_d ? close_d->cast_to_scalar() : 0;
   
   // Hi and lo are required; open/close are optional
   if (hi_data == 0   || lo_data == 0)
@@ -576,14 +592,12 @@ guppi_draw_pricebars(XyPriceBars* layer,
   
   // If there's no time data we just use the index of each price quad
 
-  if (time_data && time_data->type() != Data::Scalar)
-    {
-      g_warning("We only handle scalar time data for now.");
-      time_data = 0;
-    }
-
   ScalarData* scalar_time_data = time_data ? time_data->cast_to_scalar() : 0;
-  
+  DateData* date_time_data = time_data ? time_data->cast_to_date() : 0;
+
+  // We should have only one or the other
+  g_assert((scalar_time_data && !date_time_data) || (date_time_data && !scalar_time_data));
+
   const double* sorted_time = scalar_time_data ? scalar_time_data->sorted_scalars() : 0;
 
   const double* hi = hi_data->scalars();
@@ -600,7 +614,13 @@ guppi_draw_pricebars(XyPriceBars* layer,
 
   RGB::Context ctx(rgb);
 
-  ctx.set_line_width(3);
+  int units_per_screen = (int)rint((1.0 / (xtrans.pixels_per_unit())) * xtrans.screen_size());
+
+  gint line_width = units_per_screen > (12*30) ? 1 : 12 - (units_per_screen / 30); // 12 for 30 ups, 11 for 60, etc.
+  
+  line_width = CLAMP(line_width, 1, 5);
+
+  ctx.set_line_width(line_width);
 
   // Get the bounds of the plot area, so we can set clipping on our
   // RGB buffer target.
@@ -655,7 +675,7 @@ guppi_draw_pricebars(XyPriceBars* layer,
   // Optimize me - we can skip before and stop after the clip area.
   // Could raise open/close tests out of the loop
 
-  g_assert(N <= time_data->size());
+  g_assert(time_data == 0 || N <= time_data->size());
   g_assert(hi != 0);
   g_assert(lo != 0);
 
@@ -670,6 +690,8 @@ guppi_draw_pricebars(XyPriceBars* layer,
 
       if (sorted_time != 0)
         timeval = sorted_time[pt];
+      else if (date_time_data != 0)
+        timeval = date_time_data->get_date_julian(pt);
       else
         timeval = double(pt);
 
