@@ -289,6 +289,8 @@ public:
   double y() const { return y_; }
   double width() const { return w_; }
   double height() const { return h_; }
+  double x2() const { return x_ + w_; }
+  double y2() const { return y_ + h_; }
 
   void set(double x, double y, double w, double h) 
   {
@@ -378,6 +380,10 @@ public:
     return (r_ << 24) + (g_ << 16) + (b_ << 8) + a_;
   }
 
+  guint32 rgb() const {
+    return (r_ << 16) + (g_ << 8) + b_;
+  }
+
   void set_rgba(guint32 rgba) {
     r_ = rgba >> 24;
     g_ = (rgba >> 16) & 0xff;
@@ -433,6 +439,10 @@ public:
 
   const Color & color() const { return color_; }
 
+  Color & label_color() { return label_color_; }
+
+  const Color & label_color() const { return label_color_; }
+
   const string & label() const { return label_; }
 
   void set_label(const string & label) { label_ = label; }
@@ -463,6 +473,7 @@ private:
   double pos_;
   double len_; 
   Color color_; 
+  Color label_color_;
   string label_;
   VFont* font_;
   // can both be set
