@@ -27,4 +27,22 @@
 
 #include "printer.h"
 
+#define C1 0.552
+void
+Printer::circle(double cx, double cy, double r)
+{
+  moveto (cx + r, cy);
+  curveto (cx + r, cy - C1 * r,
+           cx + C1 * r, cy - r,
+           cx, cy - r);
+  curveto (cx - C1 * r, cy - r,
+           cx - r, cy - C1 * r,
+           cx - r, cy);
+  curveto (cx - r, cy + C1 * r,
+           cx - C1 * r, cy + r,
+           cx, cy + r);
+  curveto (cx + C1 * r, cy + r,
+           cx + r, cy + C1 * r,
+           cx + r, cy);
+}
 
