@@ -398,9 +398,9 @@ SortedPair::grab_data(ScalarData** dp)
   ScalarData* d = *dp;
   if (d != 0)
     {
-      if (!d->data_model.view_known(*this))
+      if (!d->data_model.view_known(this))
         {
-          d->data_model.add_view(*this);
+          d->data_model.add_view(this);
         }
     }
   // We don't refcount the data for now, since we expect to be used
@@ -414,9 +414,9 @@ SortedPair::release_data(ScalarData** dp)
 
   if (d != 0)
     {
-      if (d->data_model.view_known(*this))
+      if (d->data_model.view_known(this))
         {
-          d->data_model.remove_view(*this);
+          d->data_model.remove_view(this);
         }
     }
   *dp = 0;
