@@ -32,8 +32,10 @@
 class Printer;
 class XyPlotState;
 class BarPlotState;
+class PiePlotState;
 
 void guppi_print_xy(Printer* p, XyPlotState* state);
-void guppi_print_bar    (Printer* p, BarPlotState* state);
+void guppi_print_bar(Printer* p, BarPlotState* state);
+void guppi_print_pie(Printer* p, PiePlotState* state);
 
 #endif
