@@ -136,4 +136,19 @@ void guppi_register_frontend(Frontend* fe);
 // Callers should check whether this returns 0
 Frontend* guppi_frontend();
 
+class DataGroupSpecStore;
+DataGroupSpecStore* guppi_data_group_spec_store();
+
+class DataGroupSpec;
+DataGroupSpec* guppi_price_data_spec();
+
+// slots in the price data spec
+typedef enum {
+  PriceDates,
+  PriceOpens,
+  PriceHighs,
+  PriceLows,
+  PriceCloses
+} PriceDataSlotType;
+
 #endif /* GUPPI_UTIL_H */
