@@ -596,12 +596,8 @@ public:
 
   // XyPriceBars::View
 
-  virtual void change_price_data(XyPriceBars* layer, 
-                                 XyPriceBars::PriceType which,
-                                 Data* old_data, Data* new_data);
-
-  virtual void change_time_data(XyPriceBars* layer, 
-                                Data* old_data, Data* new_data);
+  virtual void change_data(XyPriceBars* layer, 
+                           Data* old_data, Data* new_data);
   
   virtual void change_data_values(XyPriceBars* layer, Data* data);
 
@@ -713,17 +709,8 @@ XyPriceView::change_hidden(XyLayer* layer,
 
 
 void 
-XyPriceView::change_price_data(XyPriceBars* layer, 
-                               XyPriceBars::PriceType which,
-                               Data* old_data, Data* new_data)
-{
-  if (item_ != 0)
-    gnome_canvas_item_request_update(item_);
-}
-
-void 
-XyPriceView::change_time_data(XyPriceBars* layer, 
-                              Data* old_data, Data* new_data)
+XyPriceView::change_data(XyPriceBars* layer, 
+                         Data* old_data, Data* new_data)
 {
   if (item_ != 0)
     gnome_canvas_item_request_update(item_);
