@@ -27,6 +27,7 @@
 #include "xyplotedit.h"
 #include "scalardata.h"
 #include "typeregistry.h"
+#include "datagroup.h"
 
 #define OUR_PAD 3
 
@@ -829,35 +830,16 @@ public:
     : XyLayerEdit(layer, state), 
       price_layer_(layer), price_widget_(0),
       changing_data_(false), 
-      time_optimize_toggle_(0),
-      prices_optimize_toggle_(0)
+      optimize_toggle_(0)
     {
-      // Only let the user choose scalar data (eventually 
-      //  the time option will also permit date data)
-      time_option_.restrict_type(Data::Scalar);
-      hi_option_.restrict_type(Data::Scalar);
-      lo_option_.restrict_type(Data::Scalar);
-      open_option_.restrict_type(Data::Scalar);
-      close_option_.restrict_type(Data::Scalar);
+      option_.restrict_type(guppi_price_data_spec()->id());
 
       // We never disconnect since the DataOption dies with us.
-      time_option_.connect(data_chosen_cb, this);
-      hi_option_.connect(data_chosen_cb, this);
-      lo_option_.connect(data_chosen_cb, this);
-      open_option_.connect(data_chosen_cb, this);
-      close_option_.connect(data_chosen_cb, this);
+      option_.connect(data_chosen_cb, this);
 
-      time_option_.set_store(state_->store());
-      hi_option_.set_store(state_->store());
-      lo_option_.set_store(state_->store());
-      open_option_.set_store(state_->store());
-      close_option_.set_store(state_->store());
+      option_.set_store(state_->store());
 
-      time_option_.set_data(price_layer_->time_data());
-      hi_option_.set_data(price_layer_->price_data(XyPriceBars::Hi));
-      lo_option_.set_data(price_layer_->price_data(XyPriceBars::Lo));
-      open_option_.set_data(price_layer_->price_data(XyPriceBars::Open));
-      close_option_.set_data(price_layer_->price_data(XyPriceBars::Close));
+      option_.set_data(price_layer_->data());
 
       price_layer_->price_model.add_view(this);
     }
@@ -868,12 +850,8 @@ public:
 
   // XyPriceBars::View
 
-  virtual void change_price_data(XyPriceBars* layer, 
-                                 XyPriceBars::PriceType which,
-                                 Data* old_data, Data* new_data);
-
-  virtual void change_time_data(XyPriceBars* layer, 
-                                Data* old_data, Data* new_data);
+  virtual void change_data(XyPriceBars* layer, 
+                           Data* old_data, Data* new_data);
   
   virtual void change_data_values(XyPriceBars* layer, Data* data);
 
@@ -894,14 +872,9 @@ protected:
 private:
   bool changing_data_;
 
-  DataOption time_option_;
-  DataOption hi_option_;
-  DataOption lo_option_;
-  DataOption open_option_;
-  DataOption close_option_;
+  DataOption option_;
 
-  GtkWidget* time_optimize_toggle_;
-  GtkWidget* prices_optimize_toggle_;
+  GtkWidget* optimize_toggle_;
 
   static void data_chosen_cb(gpointer emitter, gpointer data);
   void data_chosen(DataOption* emitter);  
@@ -913,40 +886,12 @@ private:
 };
 
 void 
-XyPriceEdit::change_price_data(XyPriceBars* layer, 
-                               XyPriceBars::PriceType which,
-                               Data* old_data, Data* new_data)
+XyPriceEdit::change_data(XyPriceBars* layer, 
+                         Data* old_data, Data* new_data)
 {
   if (!changing_data_)
     {
-      switch (which)
-        {
-        case XyPriceBars::Hi:
-          hi_option_.set_data(new_data);
-          break;
-        case XyPriceBars::Lo:
-          lo_option_.set_data(new_data);
-          break;
-        case XyPriceBars::Open:
-          open_option_.set_data(new_data);
-          break;
-        case XyPriceBars::Close:
-          close_option_.set_data(new_data);
-          break;
-        default:
-          g_assert_not_reached();
-          break;
-        }
-    }
-}
-
-void 
-XyPriceEdit::change_time_data(XyPriceBars* layer, 
-                              Data* old_data, Data* new_data)
-{
-  if (!changing_data_)
-    {
-      time_option_.set_data(new_data);
+      option_.set_data(new_data);
     }
 }
   
@@ -987,46 +932,20 @@ XyPriceEdit::ensure_price_widget()
 
   GtkWidget* vbox = gtk_vbox_new(FALSE, OUR_PAD);
 
-  make_data_hbox(vbox, _("Time Data:"), 
-                 _("Change the data set used for the time series (X axis)"), 
-                 time_option_);
-
-  make_data_hbox(vbox, _("Opens:"), 
-                 _("Change the data set used for the opening prices"), 
-                 open_option_);
-
-  make_data_hbox(vbox, _("Highs:"), 
-                 _("Change the data set used for the high prices"), 
-                 hi_option_);
-
-  make_data_hbox(vbox, _("Lows:"), 
-                 _("Change the data set used for the low prices"), 
-                 lo_option_);
-
-  make_data_hbox(vbox, _("Closes:"), 
-                 _("Change the data set used for the closing prices"), 
-                 close_option_);
+  make_data_hbox(vbox, _("Price Data:"), 
+                 _("Change the price data used"), 
+                 option_);
 
   ///
 
-  time_optimize_toggle_ = gtk_check_button_new_with_label(_("Autosize Time Axis"));
+  optimize_toggle_ = gtk_check_button_new_with_label(_("Autosize To Fit Data"));
 
-  guppi_set_tooltip(time_optimize_toggle_, _("When the data is changed, automatically adjust the X axis to best fit the data."));
+  guppi_set_tooltip(optimize_toggle_, _("When the data is changed, automatically adjust the axes to best fit the data."));
 
-  gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON(time_optimize_toggle_), TRUE);
+  gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON(optimize_toggle_), TRUE);
 
   gtk_box_pack_start(GTK_BOX(vbox),
-                     time_optimize_toggle_, FALSE, FALSE, OUR_PAD);
-
-
-  prices_optimize_toggle_ = gtk_check_button_new_with_label(_("Autosize Price Axis"));
-
-  guppi_set_tooltip(prices_optimize_toggle_, _("When the price data is changed, automatically adjust the Y axis to best fit the price data."));
-
-  gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON(prices_optimize_toggle_), TRUE);
-
-  gtk_box_pack_start(GTK_BOX(vbox),
-                     prices_optimize_toggle_, FALSE, FALSE, OUR_PAD);
+                     optimize_toggle_, FALSE, FALSE, OUR_PAD);
 
   gtk_container_add(GTK_CONTAINER(price_widget_), vbox);
 }
@@ -1056,8 +975,7 @@ XyPriceEdit::zero_widget_pointers()
 {
   XyLayerEdit::zero_widget_pointers();
   price_widget_ = 0;
-  time_optimize_toggle_ = 0;
-  prices_optimize_toggle_ = 0;
+  optimize_toggle_ = 0;
   // The data options monitor "destroy" for their widgets and zero if
   // it occurs
 }
@@ -1079,53 +997,20 @@ XyPriceEdit::data_chosen(DataOption* emitter)
 
   bool opt_prices = false;
 
-  if (emitter == &time_option_)
-    {
-      price_layer_->set_time_data(time_option_.get_data()); 
-    }
-  else if (emitter == &hi_option_)
-    {
-      price_layer_->set_price_data(XyPriceBars::Hi, 
-                                   hi_option_.get_data()); 
-      opt_prices = true;
-    }
-  else if (emitter == &lo_option_)
-    {
-      price_layer_->set_price_data(XyPriceBars::Lo, 
-                                   lo_option_.get_data()); 
-      opt_prices = true;
-    }
-  else if (emitter == &open_option_)
-    {
-      price_layer_->set_price_data(XyPriceBars::Open, 
-                                   open_option_.get_data()); 
-      opt_prices = true;
-    }
-  else if (emitter == &close_option_)
-    {
-      price_layer_->set_price_data(XyPriceBars::Close, 
-                                   close_option_.get_data()); 
-      opt_prices = true;
-    }
-  else 
-    g_warning("Emitter unknown - should not happen in %s", __FUNCTION__);
+  g_assert(emitter == &option_);
 
-  // The toggle buttons are 0 when we set the state but aren't showing 
+  price_layer_->set_data(option_.get_data());
+
+  // The toggle button is 0 when we set the state but aren't showing 
   // the window yet.
-  if (time_optimize_toggle_ != 0)
+  if (optimize_toggle_ != 0)
     {
-      if (GTK_TOGGLE_BUTTON(time_optimize_toggle_)->active)
-        state_->optimize_layers_axis(price_layer_, price_layer_->x_axis());
-    } 
-
-  if (opt_prices)
-    {
-      if (prices_optimize_toggle_ != 0)
+      if (GTK_TOGGLE_BUTTON(optimize_toggle_)->active)
         {
-          if (GTK_TOGGLE_BUTTON(prices_optimize_toggle_)->active)
-            state_->optimize_layers_axis(price_layer_, price_layer_->y_axis());
+          state_->optimize_layers_axis(price_layer_, price_layer_->x_axis());
+          state_->optimize_layers_axis(price_layer_, price_layer_->y_axis());
         }
-    }
+    } 
 
   changing_data_ = false;
 }
@@ -1721,6 +1606,10 @@ XyAxisEdit::set_current_axis_edit(AxisEdit* ae)
       
       current_axis_widget_ = new_panel;
 
+      // This glosses over a bug rather than fixing it, but oh well.
+      // (in the add below, the widget gets mapped but isn't GTK_WIDGET_VISIBLE?)
+      gtk_widget_show_all(current_axis_widget_);
+
       gtk_container_add(GTK_CONTAINER(axis_edit_slot_), current_axis_widget_);
 
       const gchar* title = NULL;
