@@ -29,6 +29,8 @@
 #include "markerstyle.h"
 #include "vfont.h"
 #include "typeregistry.h"
+#include "datagroup.h"
+#include "datedata.h"
 
 #include "guppi-math.h"
 
@@ -736,10 +738,11 @@ static bool get_min_max(XyLayer* layer, PlotUtil::PositionType pos,
 
       if (pos == layer->x_axis())
         {
-          Data* d = pl->time_data();
+          DataGroup* dg = pl->data();
+          Data* d = dg ? dg->get_data(PriceDates) : 0;
           if (d != 0)
             {
-              if (d->type() == Data::Scalar)
+              if (d->is_a(Data::Scalar))
                 {
                   ScalarData* sd = d->cast_to_scalar();
 
@@ -747,7 +750,14 @@ static bool get_min_max(XyLayer* layer, PlotUtil::PositionType pos,
                   *max = sd->max();
                   retval = true;
                 }
-              // FIXME eventually the type can be date data.
+              else if (d->is_a(Data::Date))
+                {
+                  DateData* dd = d->cast_to_date();
+
+                  *min = (double)dd->min_julian();
+                  *max = (double)dd->max_julian();
+                  retval = true;
+                }
             }
           else
             {
@@ -763,10 +773,16 @@ static bool get_min_max(XyLayer* layer, PlotUtil::PositionType pos,
         }
       else if (pos == layer->y_axis())
         {
-          ScalarData* hi_sd = pl->price_data(XyPriceBars::Hi);
-          ScalarData* lo_sd = pl->price_data(XyPriceBars::Lo);
-          if (hi_sd && lo_sd)
+          DataGroup* dg = pl->data();
+          Data* hi_d = dg ? dg->get_data(PriceHighs) : 0;
+          Data* lo_d = dg ? dg->get_data(PriceLows) : 0;
+          if (hi_d && lo_d)
             {
+              ScalarData* hi_sd = hi_d->cast_to_scalar();
+              ScalarData* lo_sd = lo_d->cast_to_scalar();
+
+              g_assert(hi_sd && lo_sd);
+
               *min = lo_sd->min();
               *max = hi_sd->max();
               retval = true;
