@@ -240,7 +240,7 @@ PlotShell::~PlotShell()
 {
   if (plot_) 
     {
-      plot_->plot_model.remove_view(*this);
+      plot_->plot_model.remove_view(this);
       plot_->unrealize();
       if (plot_->unref() == 0)
         delete plot_;
@@ -300,7 +300,7 @@ PlotShell::set_plot(Plot* p)
       ++i;
     }
 
-  plot_->plot_model.add_view(*this);
+  plot_->plot_model.add_view(this);
 
   plot_->realize(GNOME_CANVAS_GROUP(GNOME_CANVAS(canvas_)->root));
 
