@@ -27,9 +27,9 @@
 #include "textimport.h"
 
 #include "libguppi/scalardata.h"
+#include "libguppi/dataimport.h"
 #include "guppidata.h"
 
-#include "goose/AsciiImport.h"
 #include "goose/RealSet.h"
 
 #include <errno.h>
@@ -60,112 +60,84 @@ private:
 };
 
 
-// If we return an error, then fillme should remain empty.
-
+// fillme should be empty if an error is returned.
 gchar*
 guppi_text_import(const string& filename, vector<Data*> & fillme, bool with_gui)
 {
-  FILE* f = fopen(filename.c_str(), "r");
+  StackWarningController wc;    
+  vector<string> errors;
+  vector<vector<double> > columns;
   
-  if (f == NULL) 
-    {
-      gchar buf[256];
-      g_snprintf(buf, 256, _("Unable to open `%s', %s"), filename.c_str(), strerror(errno)); 
-      return g_strdup(buf);
-    }
+  wc.set_see_warnings(10); // at most 10 warnings are displayed.
+  
+  ProgressDialog pd(_("Importing file..."));
 
-  try {
-    StackWarningController wc;    
-    
-    wc.set_see_warnings(10); // at most 10 warnings are displayed.
-    
-    FILEAsciiReader car(f, wc);
+
+  guppi_import_doubles(filename.c_str(),
+                       columns,
+                       wc,
+                       errors,
+                       &pd);
+  
+  if (!errors.empty())
+    {
+      string all_errors;
       
-    ProgressDialog pd(_("Importing file..."));
-
-    AsciiImport ai(car, wc, &pd);
-  
-    ai.autosetup();
-  
-    ai.import();
-  
-    const vector<string>& names = ai.headings();
-    const vector<DataSet*>& sets = ai.datasets();
-  
-    vector<string>::const_iterator ni = names.begin();
-    vector<DataSet*>::const_iterator i = sets.begin();
-    while (i != sets.end())
-      {
-        RealSet* rs = 0; 
+      vector<string>::const_iterator ei = errors.begin();
+      while (ei != errors.end())
+        {
+          all_errors += *ei;
+          all_errors += "\n";
           
-        if ((*i)->type() == RealSet::typecode)
-          rs = static_cast<RealSet*>(*i);
-        else 
-          {
-            wc.warn("Non-scalar column ignored in import file");
-            // it will never be gc'd since we aren't creating a smob 
-            //  from it, so nuke it.
-            delete *i;
-          }
-              
-        if (ni != names.end())
-          {
-            if (rs != 0)
-              {
-                if ((*ni).empty())
-                  rs->set_label(_("Imported Data"));
-                else
-                  rs->set_label(*ni);
-              }
-            ++ni;
-          }
-
-        if (rs != 0)
-          {
-            Data* d = new ScalarData(rs);
-            fillme.push_back(d);
-          }
-          
-        ++i;
-      }
-
-    // Clean up the AsciiImport
-    AsciiImport::delete_dataconverters(ai.dataconverters());
-
-    string all_warnings;
-
-    const vector<string>& warns = wc.get_warnings();
-    vector<string>::const_iterator wi = warns.begin();
-    while (wi != warns.end())
-      {
-        all_warnings += *wi;
-        all_warnings += "\n";
-        
-        ++wi;
-      }
-
-    if (with_gui)
-      {
-        GtkWidget* dialog = gnome_warning_dialog(all_warnings.c_str());
-        guppi_setup_dialog(dialog);
-      }
-  }
-  catch (Exception & e)
-    {
-      fclose(f); // check error?
-      return g_strconcat(_("Failed to import: "), e.what().c_str(), NULL);
+          ++ei;
+        }
+      
+      return g_strdup(all_errors.c_str());
     }
-  catch (...)
+  else 
     {
-      // What the fuck, over
-      g_warning("Should not happen, unknown exception in text import");
+      guint i = 0;
+      while (i < columns.size())
+        {
+          g_debug("%u values in column %u\n", columns[i].size(), i);
 
-      fclose(f);
+          ScalarData* sd = new ScalarData;
 
-      return g_strdup(_("Text import failed mysteriously; some sort of bug in the software."));
+          // This is gratuitously slow; should be just a memcpy
+          vector<double>::const_iterator ci = columns[i].begin();
+          while (ci != columns[i].end())
+            {
+              sd->add(*ci);
+              ++ci;
+            }
+
+          char* tmp = g_strdup_printf(_("Imported Data %u"), i);
+          sd->set_name(tmp);
+          g_free(tmp);
+
+          fillme.push_back(sd);
+
+          ++i;
+        }
     }
 
-  fclose(f);
+  string all_warnings;
+  
+  const vector<string>& warns = wc.get_warnings();
+  vector<string>::const_iterator wi = warns.begin();
+  while (wi != warns.end())
+    {
+      all_warnings += *wi;
+      all_warnings += "\n";
+      
+      ++wi;
+    }
+
+  if (!all_warnings.empty() && with_gui)
+    {
+      GtkWidget* dialog = gnome_warning_dialog(all_warnings.c_str());
+      guppi_setup_dialog(dialog);
+    }
 
   return 0;
 }
@@ -373,3 +345,118 @@ ProgressDialog::set_operation(const string& opname)
   while (gtk_events_pending())
     gtk_main_iteration();
 }
+
+
+// Old cruft
+#if 0
+#include "goose/AsciiImport.h"
+// If we return an error, then fillme should remain empty.
+gchar*
+guppi_text_import(const string& filename, vector<Data*> & fillme, bool with_gui)
+{
+  FILE* f = fopen(filename.c_str(), "r");
+  
+  if (f == NULL) 
+    {
+      gchar buf[256];
+      g_snprintf(buf, 256, _("Unable to open `%s', %s"), filename.c_str(), strerror(errno)); 
+      return g_strdup(buf);
+    }
+
+
+  try {
+    StackWarningController wc;    
+    
+    wc.set_see_warnings(10); // at most 10 warnings are displayed.
+
+    ProgressDialog pd(_("Importing file..."));
+
+    FILEAsciiReader car(f, wc);
+
+    AsciiImport ai(car, wc, &pd);
+  
+    ai.autosetup();
+  
+    ai.import();
+  
+    const vector<string>& names = ai.headings();
+    const vector<DataSet*>& sets = ai.datasets();
+  
+    vector<string>::const_iterator ni = names.begin();
+    vector<DataSet*>::const_iterator i = sets.begin();
+    while (i != sets.end())
+      {
+        RealSet* rs = 0; 
+          
+        if ((*i)->type() == RealSet::typecode)
+          rs = static_cast<RealSet*>(*i);
+        else 
+          {
+            wc.warn("Non-scalar column ignored in import file");
+            // it will never be gc'd since we aren't creating a smob 
+            //  from it, so nuke it.
+            delete *i;
+          }
+              
+        if (ni != names.end())
+          {
+            if (rs != 0)
+              {
+                if ((*ni).empty())
+                  rs->set_label(_("Imported Data"));
+                else
+                  rs->set_label(*ni);
+              }
+            ++ni;
+          }
+
+        if (rs != 0)
+          {
+            Data* d = new ScalarData(rs);
+            fillme.push_back(d);
+          }
+          
+        ++i;
+      }
+
+    // Clean up the AsciiImport
+    AsciiImport::delete_dataconverters(ai.dataconverters());
+
+    string all_warnings;
+
+    const vector<string>& warns = wc.get_warnings();
+    vector<string>::const_iterator wi = warns.begin();
+    while (wi != warns.end())
+      {
+        all_warnings += *wi;
+        all_warnings += "\n";
+        
+        ++wi;
+      }
+
+    if (with_gui)
+      {
+        GtkWidget* dialog = gnome_warning_dialog(all_warnings.c_str());
+        guppi_setup_dialog(dialog);
+      }
+  }
+  catch (Exception & e)
+    {
+      fclose(f); // check error?
+      return g_strconcat(_("Failed to import: "), e.what().c_str(), NULL);
+    }
+  catch (...)
+    {
+      // What the fuck, over
+      g_warning("Should not happen, unknown exception in text import");
+
+      fclose(f);
+
+      return g_strdup(_("Text import failed mysteriously; some sort of bug in the software."));
+    }
+
+  fclose(f);
+
+  return 0;
+}
+#endif
